@@ -97,6 +97,7 @@ fake_data_0_backup_metadata = {
 def get_fake_backup_metadata():
     return copy.deepcopy(fake_data_0_backup_metadata)
 
+
 fake_malformed_data_0_backup_metadata = {
     "hostname": "alpha",
     "backup_name": "important_data_backup",
@@ -199,7 +200,7 @@ fake_job_0 = {
             "freezer_action": {
                 "action": "backup",
                 "mode": "fs",
-                "src_file": "/home/tylerdurden/project_mayhem",
+                "path_to_backup": "/home/tylerdurden/project_mayhem",
                 "backup_name": "project_mayhem_backup",
                 "container": "my_backup_container"
             },
@@ -244,7 +245,7 @@ fake_job_2 = {
             "freezer_action": {
                 "action": "backup",
                 "mode": "fs",
-                "src_file": "/home/tylerdurden/project_mayhem",
+                "path_to_backup": "/home/tylerdurden/project_mayhem",
                 "backup_name": "project_mayhem_backup",
                 "container": "my_backup_container1"
             },
@@ -288,7 +289,7 @@ fake_job_3 = {
             "freezer_action": {
                 "action": "backup",
                 "mode": "fs",
-                "src_file": "/home/tylerdurden/project_mayhem",
+                "path_to_backup": "/home/tylerdurden/project_mayhem",
                 "backup_name": "project_mayhem_backup",
                 "container": "my_backup_container1"
             },
@@ -424,12 +425,13 @@ def get_fake_client_1():
 def get_fake_client_id():
     return uuid.uuid4().hex
 
+
 fake_action_0 = {
     "freezer_action":
         {
             "action": "backup",
             "mode": "fs",
-            "src_file": "/home/tylerdurden/project_mayhem",
+            "path_to_backup": "/home/tylerdurden/project_mayhem",
             "backup_name": "project_mayhem_backup",
             "container": "my_backup_container",
         },
@@ -448,7 +450,7 @@ fake_action_1 = {
         {
             "action": "backup",
             "mode": "fs",
-            "src_file": "/home/tylerdurden/project_mayhem",
+            "path_to_backup": "/home/tylerdurden/project_mayhem",
             "backup_name": "project_mayhem_backup",
             "container": "my_backup_container",
         },
@@ -467,7 +469,7 @@ fake_action_2 = {
         {
             "action": "restore",
             "mode": "fs",
-            "src_file": "/home/tecs/project_tecs",
+            "path_to_backup": "/home/tecs/project_tecs",
             "backup_name": "project_tecs_restore",
             "container": "my_restore_container",
         },
@@ -485,7 +487,7 @@ fake_action_3 = {
         {
             "action": "restore",
             "mode": "fs",
-            "src_file": "/home/tecs/project_tecs",
+            "path_to_backup": "/home/tecs/project_tecs",
             "backup_name": "project_tecs_restore",
             "container": "my_restore_container",
         },
@@ -517,6 +519,7 @@ def get_fake_action_id():
 def get_fake_action_3():
     return copy.deepcopy(fake_action_3)
 
+
 fake_session_0 = {
     "session_id": 'turistidellademocrazia',
     "session_tag": 5,
